Add a ``mask_invalid`` option to ``Table.read`` to allow deactivating the
masking of NaNs in float columns and empty strings in string columns. This
option is necessary to allow effective use of memory-mapped reading with
``memmap=True``.
